@@ -111,13 +111,16 @@ class LockssPreservation(models.Model):
         return "LOCKSS"
 
     @staticmethod
-    def preservation(container_title: str, issn: str, volume: str, no=None):
+    def preservation(
+        container_title: str, issn: str, volume: str, no=None, year=None
+    ):
         """
         Determine whether a DOI is preserved in LOCKSS
         :param container_title: the container title
         :param issn: the ISSN
         :param volume: the volume
         :param no: the issue number
+        :param year: the year
         :return: A LockssPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -215,13 +218,16 @@ class CarinianaPreservation(models.Model):
         return "Cariniana"
 
     @staticmethod
-    def preservation(container_title: str, issn: str, volume: str, no=None):
+    def preservation(
+        container_title: str, issn: str, volume: str, no=None, year=None
+    ):
         """
         Determine whether a DOI is preserved in Cariniana
         :param container_title: the container title
         :param issn: the ISSN
         :param volume: the volume
         :param no: the issue number
+        :param year: the year
         :return: A Cariniana item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -319,13 +325,16 @@ class ClockssPreservation(models.Model):
         return "CLOCKSS"
 
     @staticmethod
-    def preservation(container_title: str, issn: str, volume: str, no=None):
+    def preservation(
+        container_title: str, issn: str, volume: str, no=None, year=None
+    ):
         """
         Determine whether a DOI is preserved in CLOCKSS
         :param container_title: the container title
         :param issn: the ISSN
         :param volume: the volume
         :param no: the issue number
+        :param year: the year
         :return: A ClockssPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -413,13 +422,14 @@ class PKPPreservation(models.Model):
         return "PKP PLN"
 
     @staticmethod
-    def preservation(container_title, issn, volume, no):
+    def preservation(container_title, issn, volume, no, year=None):
         """
         Determine whether a DOI is preserved in the PKP private LOCKSS network
         :param container_title: the container title
         :param issn: the ISSN
         :param volume: the volume
         :param no: the issue number
+        :param year: the year
         :return: A PKPPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -496,13 +506,14 @@ class HathiPreservation(models.Model):
         return "HathiTrust"
 
     @staticmethod
-    def preservation(container_title, issn, volume, no=None):
+    def preservation(container_title, issn, volume, no=None, year=None):
         """
         Determine whether a DOI is preserved in HathiTrust
         :param container_title: the container title
         :param issn: the ISSN
         :param volume: the volume
         :param no: the issue number
+        :param year: the year
         :return: A HathiPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -514,15 +525,48 @@ class HathiPreservation(models.Model):
             return None, False
 
         if preserved_item:
+            # HathiTrust records volume strings as "v[1, 2]" etc
+            # but also as "v1999" etc.
+
+            if year:
+                volume_year_regex = re.compile(rf"v{year}")
+                volume_year_regex_two = re.compile(rf"{year}")
+
+                for pi in preserved_item:
+                    matches = re.findall(
+                        volume_year_regex, pi.preserved_volumes
+                    )
+
+                    if matches:
+                        return pi, True
+
+                    matches = re.findall(
+                        volume_year_regex_two, pi.preserved_volumes
+                    )
+
+                    if matches:
+                        return pi, True
+
+            volume_regex = r"(\d+),?"
+
             volume = str(volume)
 
             for pi in preserved_item:
-                vols = [x.strip() for x in pi.preserved_volumes.split(";")]
+                matches = re.finditer(
+                    volume_regex, pi.preserved_volumes, re.MULTILINE
+                )
+
+                for matchNum, match in enumerate(matches, start=1):
+                    for groupNum in range(0, len(match.groups())):
+                        groupNum = groupNum + 1
+
+                        group = match.group(groupNum)
+
+                        if group == volume:
+                            return pi, True
+
+            return None, False
 
-                if volume in vols:
-                    return pi, True
-                else:
-                    return None, False
         else:
             return None, False
 
@@ -654,13 +698,14 @@ class PorticoPreservation(models.Model):
         return "Portico"
 
     @staticmethod
-    def preservation(container_title, issn, volume, no=None):
+    def preservation(container_title, issn, volume, no=None, year=None):
         """
         Determine whether a DOI is preserved in Portico
         :param container_title: the container title
         :param issn: the ISSN
         :param volume: the volume
         :param no: the issue number
+        :param year: the year
         :return: A PorticoPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -791,13 +836,14 @@ class OculScholarsPortalPreservation(models.Model):
         return "OCUL Scholars Portal"
 
     @staticmethod
-    def preservation(container_title, issn, volume, no=None):
+    def preservation(container_title, issn, volume, no=None, year=None):
         """
         Determine whether a DOI is preserved in OCUL Scholars Portal
         :param container_title: the container title
         :param issn: the ISSN
         :param volume: the volume
         :param no: the issue number
+        :param year: the year
         :return: An OculScholarsPortalPreservation item (or None) and a bool
         indicating whether the item is fully preserved
         """
@@ -856,23 +902,6 @@ class OculScholarsPortalPreservation(models.Model):
             pis = preserved_item.filter(preserved_volumes=volume)
             return None, False
 
-        # OCUL gives volume formats as follows:
-        # v24(1)
-        # 1, 2, 3-4, 3.4
-        # 1 to 4
-        volume_regex = r"v(\d+)"
-
-        for pis in preserved_item:
-            print(pis.preserved_volumes)
-            matches = re.findall(volume_regex, pis.preserved_volumes)
-
-            volume = str(volume)
-
-            if volume in matches:
-                return pis, pis.preserved
-
-        return None, False
-
     @staticmethod
     def import_data(url, bucket="", s3client=None):
         # download the data file from S3 bucket
@@ -983,3 +1012,141 @@ class ISSN(models.Model):
 
     identifier = models.CharField(max_length=255)
     issnl = models.ForeignKey(ISSNL, on_delete=models.CASCADE, default=None)
+
+
+class InternetArchivePreservation(models.Model):
+    class Meta:
+        db_table = "preservationData_iapreservation"
+
+        indexes = [
+            models.Index(fields=["issn"]),
+            models.Index(fields=["eissn"]),
+            models.Index(fields=["title"]),
+        ]
+
+    title = models.TextField()
+    issn = models.CharField(max_length=20)
+    eissn = models.CharField(max_length=20)
+    preserved_volumes = models.TextField()
+
+    # this indicates whether the title is preserved or queued
+    preserved = models.BooleanField()
+    publisher = models.ForeignKey(
+        Publisher, on_delete=models.CASCADE, default=None
+    )
+
+    def __str__(self):
+        return "{} (issn: {}) (eissn: {}) (v{}) ".format(
+            self.title, self.issn, self.eissn, self.preserved_volumes
+        )
+
+    @staticmethod
+    def name():
+        return "Internet Archive"
+
+    @staticmethod
+    def preservation(container_title, issn, volume, no=None, year=None):
+        """
+        Determine whether a DOI is preserved in the Internet Archive
+        :param container_title: the container title
+        :param issn: the ISSN
+        :param volume: the volume
+        :param no: the issue number
+        :param year: the year
+        :return: An InternetArchivePreservation item (or None) and a bool
+        indicating whether the item is fully preserved
+        """
+        preserved_item = utils.get_preserved_item_record(
+            InternetArchivePreservation, container_title, issn
+        )
+
+        if not preserved_item or len(preserved_item) == 0:
+            return None, False
+
+        # We add a single IA entry per volume
+        pi = preserved_item.filter(volume=str(volume))
+
+        if pi.count() > 0:
+            return pi, pi.preserved
+
+        return None, False
+
+    @staticmethod
+    @transaction.atomic
+    def import_data(url, bucket="", s3client=None, local=False):
+        # download the data file from S3 bucket
+        with tempfile.TemporaryDirectory() as tmp:
+            if local:
+                path = url
+            else:
+                path = Path(tmp) / "downloaded.file"
+
+                ia_data = utils.download_remote(
+                    False,
+                    InternetArchivePreservation,
+                    url,
+                    bucket=bucket,
+                    s3client=s3client,
+                    decode=False,
+                    file=True,
+                    filename=str(path),
+                )
+
+            # clear out existing data
+            utils.clear_out(InternetArchivePreservation)
+
+            csv.field_size_limit(sys.maxsize)
+
+            with open(str(path), "r") as input_file:
+                csv_reader = csv.DictReader(input_file, delimiter="\t")
+
+                for row in csv_reader:
+                    publisher, created = Publisher.objects.get_or_create(
+                        name=row["publisher_name"]
+                    )
+
+                    # we have to calculate the held volumes
+                    first_vol = row["num_first_vol_online"]
+                    last_vol = row["num_last_vol_online"]
+
+                    if first_vol != "":
+                        try:
+                            first_vol = int(first_vol)
+                        except ValueError:
+                            first_vol = None
+
+                    if last_vol != "":
+                        try:
+                            last_vol = int(last_vol)
+                        except ValueError:
+                            last_vol = None
+
+                    volumes = []
+
+                    if first_vol and last_vol is None:
+                        # if no last volume, assume single volume
+                        volumes.append(first_vol)
+                    elif last_vol and first_vol is None:
+                        # if no first volume, assume single volume
+                        volumes.append(last_vol)
+                    elif first_vol and last_vol:
+                        # if there's a first and last volume
+                        volumes.extend(range(first_vol, last_vol))
+
+                    volumes = set(volumes)
+
+                    for vol in volumes:
+                        InternetArchivePreservation.objects.create(
+                            issn=row["print_identifier"],
+                            eissn=row["online_identifier"],
+                            title=row["publication_title"],
+                            preserved_volumes=str(vol),
+                            preserved=True,
+                            publisher=publisher,
+                        )
+
+                    logging.info(
+                        f'Added {row["publication_title"]} to '
+                        f"{InternetArchivePreservation.name()} data "
+                        f"({len(volumes)} volumes)"
+                    )
